@@ -2,12 +2,15 @@ import sys
 import zipfile
 from io import BytesIO
 from typing import Union
-
+import warnings
 import bs4
+from bs4.builder import XMLParsedAsHTMLWarning
 import pandas as pd
 
 from .mappings import PSRTYPE_MAPPINGS, DOCSTATUS, BSNTYPE, Area
 
+warnings.filterwarnings('ignore', category=XMLParsedAsHTMLWarning)
+
 GENERATION_ELEMENT = "inBiddingZone_Domain.mRID"
 CONSUMPTION_ELEMENT = "outBiddingZone_Domain.mRID"
 
@@ -134,8 +137,8 @@ def parse_generation(
             # If not, we just save ts
             all_series[ts.name] = ts
         else:
-            # If yes, we append to it
-            series = series.append(ts)
+            # If yes, we extend it
+            series = pd.concat([series, ts])
             series.sort_index(inplace=True)
             all_series[series.name] = series
 
@@ -205,7 +208,7 @@ def parse_installed_capacity_per_plant(xml_text):
         if series is None:
             all_series[s.name] = s
         else:
-            series = series.append(s)
+            series = pd.concat([series, s])
             series.sort_index()
             all_series[series.name] = series
 
